@@ -8,27 +8,41 @@ Sample usage:
 
 	# flickr.test.echo:
 	api = Flickr.API.API(key, secret)
-	test_response = api.execute_method(method='flickr.test.echo')
-	test_response.dump()
+	test_rsp = api.execute_method(method='flickr.test.echo', sign=False)
+	if test_rsp.code == 200:
+		print test_rsp.read()
 
 	# flickr.auth.getFrob:
 	frob_request = Flickr.API.Request(method='flickr.auth.getFrob')
-	frob_response = api.execute_request(frob_request)
-	if frob_response.success:
-		frob = frob_response.et.findtext('frob')
+	frob_rsp = api.execute_request(frob_request)
+	if frob_rsp.code == 200:
+		frob_rsp_et = xml.etree.ElementTree.parse(frob_rsp)
+		if frob_rsp_et.getroot().get('stat') == 'ok':
+			frob = frob_rsp_et.findtext('frob')
 	
 	# get the desktop authentication url
-	url = api.get_auth_url(frob, 'write')
+	auth_url = api.get_auth_url(frob, 'write')
 
 	# ask the user to authorize your app now using that url
+	print "auth me:  %s" % (auth_url,)
+	input = raw_input("done [y]: ")
+	if input.lower() not in ('', 'y', 'yes'):
+		sys.exit()
 
 	# flickr.auth.getToken:
-	token_response = api.execute_request(Flickr.API.Request(method='flickr.auth.getToken', frob=frob))
-	if token_response.success:
-		token = token_response.et.find('auth').findtext('token')
+	token_rsp = api.execute_request(Flickr.API.Request(method='flickr.auth.getToken', frob=frob, format='json', nojsoncallback=1))
+	if token_rsp.code == 200:
+		token_rsp_json = simplejson.load(token_rsp)
+		if token_rsp_json['stat'] == 'ok':
+			token = str(token_rsp_json['auth']['token']['_content'])
 
 	# flickr.activity.userPhotos (requires authentication):
-	activity = api.execute_request(Flickr.API.Request(method='flickr.activity.userPhotos', auth_token=token, timeframe='1d'))
+	activity_rsp = api.execute_request(Flickr.API.Request(method='flickr.activity.userPhotos', auth_token=token, timeframe='1d', format='rest'))
+	if activity_rsp.code == 200:
+		activity_rsp_et = xml.etree.ElementTree.parse(activity_rsp)
+		if activity_rsp_et.getroot().get('stat') == 'ok':
+			# do something with the activity
+			xml.etree.ElementTree.dump(activity_rsp_et)
 
 	# upload
 	photo = open('photo.jpg', 'rb')
@@ -40,12 +54,7 @@ Sample usage:
 """
 
 __author__ = "Gilad Raphaelli"
-__version__ = "0.3.1"
-
-try:
-	import xml.etree.cElementTree as ET
-except ImportError:
-	import cElementTree as ET
+__version__ = "0.4"
 
 import md5,mimetypes,urllib,urllib2
 import warnings
@@ -109,7 +118,7 @@ class API:
 		self.secret = secret
 
 	def execute_method(self, method, args={}, sign=True):
-		""" Given a Flickr API method and arguments, construct a Flickr.API.Request and return a Flickr.API.Response """
+		""" Given a Flickr API method and arguments, construct a Flickr.API.Request and return a urllib2.addinfourl """
 		args['method'] = method
 		return self.execute_request(Request(**args), sign)
 
@@ -123,21 +132,20 @@ class API:
 		return self.execute_request(Request(url='http://api.flickr.com/services/upload/',**args), sign=True, encode=encode_multipart_formdata)
 
 	def execute_request(self, request, sign=True, encode=encode_urlencode):
-		""" Given a Flickr.API.Request return a Flickr.API.Response, altering the original Request """
+		""" Given a Flickr.API.Request return a Flickr.API.Response, altering
+		the original Request.  The request will silently not sign if no secret
+		is available. """
 		
 		request.args['api_key'] = self.key
 
-		if sign:
-			if self.secret is None:
-				warnings.warn("no secret provided, unable to sign request (maybe you want sign=False?).  sending unsigned request.", APIWarning)
-			else:
-				# Sign args as they are now, except photo
-				args_to_sign = {}
-				for (k,v) in request.args.items():
-					if k not in ('photo'):
-						args_to_sign[k] = v
-					
-				request.args['api_sig'] = self._sign_args(args_to_sign)
+		if sign and self.secret is not None:
+			# Sign args as they are now, except photo
+			args_to_sign = {}
+			for (k,v) in request.args.items():
+				if k not in ('photo'):
+					args_to_sign[k] = v
+				
+			request.args['api_sig'] = self._sign_args(args_to_sign)
 
 		request.add_header('Host', request.get_host())
 
@@ -150,12 +158,7 @@ class API:
 		if (request.get_method() != "POST"):
 			raise Exception, "not a POST? Something is wrong here"
 
-		response = Response(urllib2.urlopen(request))
-
-		if (response.response.code != 200):
-			raise APIError, ("API Returned an HTTP %s code '%s'" % (response.response.code,response.response.msg), response)
-
-		return response
+		return urllib2.urlopen(request)
 
 	def get_auth_url(self, frob, perms):
 		""" Given a frob obtained via a 'flickr.auth.getFrob' and perms (currently read, write, or delete) return a url for client api authorization """
@@ -177,27 +180,6 @@ class Request(urllib2.Request):
 		urllib2.Request.__init__(self, url=url)
 		self.args = args
 
-class Response:
-	""" A response from the Flickr API """
-	def __init__(self, response):
-		self.response = response
-		self.et = ET.parse(response)
-
-		rsp = self.et.getroot()
-		if rsp.tag != "rsp":
-			raise APIError, "unexpected response from Flickr API, expecting <rsp>..</rsp>, got <%s>" % (rsp.tag,)
-
-		self.status = rsp.get("stat")
-		self.success = (self.status == 'ok')
-
-		if not self.success:
-			err = rsp.find("err")
-			self.error_code = err.get("code")
-			self.error_msg = err.get("msg")
-	
-	def dump(self):
-		ET.dump(self.et)
-
 if (__name__ == '__main__'):
 	import sys
 	try:
@@ -209,5 +191,3 @@ if (__name__ == '__main__'):
 
 	api = API(key, secret)
 	res = api.execute_method(method='flickr.test.echo', args={'foo':'bar'})
-
-	res.dump()
